
class TooManyRequests(Exception):
    pass


class InternalServerError(Exception):
    pass


class UnexpectedError(Exception):
    pass


class ExecutionError(Exception):
    pass


class InvalidLanguage(Exception):
    pass
